@@ -12,7 +12,7 @@ from OpenSSL import crypto
 def get_apns_certificate(cert_path, cert_pw):
     p12 = crypto.load_pkcs12(open(cert_path, 'rb').read(), cert_pw)
     pem = crypto.dump_privatekey(crypto.FILETYPE_PEM, p12.get_privatekey())
-    return pem
+    return pem.decode("utf-8")
 
 
 class NotificationStack(Stack): 
@@ -32,7 +32,7 @@ class NotificationStack(Stack):
             # the properties below are optional
             bundle_id=apns_bundle_id,
             # certificate=apns_certificate.get_certificate(),
-            default_authentication_method="certificate",
+            default_authentication_method="key",
             enabled=True,
             private_key=apns_certificate,
             # team_id="teamId",
